@@ -1,7 +1,13 @@
-import json
-import pytest
-import time
+import logging
 import os
+import time
+
+import pytest
+from flask import Flask
+from flask_restful import Api
+
+from scraper.restful.endpoints import create_routes
+
 
 # noinspection PyProtectedMember
 @pytest.fixture
@@ -9,6 +15,15 @@ def fixture_directory():
     return os.path.join(os.path.dirname(__file__), "fixtures")
 
 
+@pytest.fixture(scope='function')
+def app():
+    app = Flask("test")
+    api = Api(app)
+    create_routes(api)
+    app.logger.setLevel(logging.DEBUG)
+    return app
+
+
 def mock_resource_with(filename, resource_type):
     """
     Mocks an HTTP request by pulling text from a pre-downloaded file
